setup

package
v0.0.0-...-61418c2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2023 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Logging

func Logging() *logrus.Logger

Logging sets up the logging for the router daemon

Types

type Config

type Config struct {
	RegionFile       string `envconfig:"REGIONS_FILE" default:"config/regions/all.yaml"`
	KubeconfigFolder string `envconfig:"KUBECONFIG_FOLDER" default:"config/kubeconfig/"`
}

Config has all the fields to expose config

func LoadConfig

func LoadConfig() (*Config, error)

LoadConfig loads the configuration from the environment variables and returns a Config struct and an error

type KubernetesConfigs

type KubernetesConfigs struct {
	Configs map[string]*rest.Config
}

KubernetesConfigs has all the fields to expose Kubernetes configs

func BuildKubernetesConfigs

func BuildKubernetesConfigs(log *logrus.Entry, config *Config) KubernetesConfigs

BuildKubernetesConfigs builds the Kubernetes configs

type Region

type Region struct {
	Code string `json:"code" yaml:"code"`
	Name string `json:"name" yaml:"name"`
}

Region has all the fields to expose regions

func ListRegions

func ListRegions(log *logrus.Entry, regionFile string) []Region

ListRegions returns a list of regions

Jump to