Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
RegionFile string `envconfig:"REGIONS_FILE" default:"config/regions/all.yaml"`
KubeconfigFolder string `envconfig:"KUBECONFIG_FOLDER" default:"config/kubeconfig/"`
}
Config has all the fields to expose config
func LoadConfig ¶
LoadConfig loads the configuration from the environment variables and returns a Config struct and an error
type KubernetesConfigs ¶
KubernetesConfigs has all the fields to expose Kubernetes configs
func BuildKubernetesConfigs ¶
func BuildKubernetesConfigs(log *logrus.Entry, config *Config) KubernetesConfigs
BuildKubernetesConfigs builds the Kubernetes configs
Click to show internal directories.
Click to hide internal directories.